@@ -32,6 +32,9 @@ pub fn filter<'a>(
         impl_item_arg1!(input, name, arguments, FlipStateFilter);
         impl_item_arg1!(input, name, arguments, TimeMatchesCronExpressionFilter);
         impl_item_arg2!(input, name, arguments, StateMoreThanConstFilter);
+        impl_item_arg2!(input, name, arguments, StateLessThatConstFilter);
+        impl_item_arg2!(input, name, arguments, SetStateToStateFilter);
+        impl_item_arg2!(input, name, arguments, StateEqualToStateFilter);
 
         Err(Err::Error(ParserError::Base {
             location: name,
@@ -138,4 +141,25 @@ mod tests {
         ("0xabababab~u32", 0xabab_abab),
         ("0xbabababa~u32", Value::U32(0xbaba_baba))
     );
+    impl_tests_for_item_arg2!(
+        state_less_than_const_filter,
+        filter,
+        StateLessThatConstFilter,
+        ("0xabababab~u32", 0xabab_abab),
+        ("0xbabababa~u32", Value::U32(0xbaba_baba))
+    );
+    impl_tests_for_item_arg2!(
+        set_state_to_state_filter,
+        filter,
+        SetStateToStateFilter,
+        ("0xabababab~u32", 0xabab_abab),
+        ("0xbabababa~u32", 0xbaba_baba)
+    );
+    impl_tests_for_item_arg2!(
+        state_equal_to_state_filter,
+        filter,
+        StateEqualToStateFilter,
+        ("0xabababab~u32", 0xabab_abab),
+        ("0xbabababa~u32", 0xbaba_baba)
+    );
 }
